@@ -2,10 +2,11 @@
  * @package      hubzero-usermap
  * @file         usermap.c
  * @author       Rick Kennell <kennell@purdue.edu>
- * @copyright    Copyright (c) 2005-2012 HUBzero Foundation, LLC.
+ * @author       Nicholas J. Kisseberth <nkissebe@purdue.edu>
+ * @copyright    Copyright (c) 2005-2013 HUBzero Foundation, LLC.
  * @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
  *
- * Copyright (c) 2005-2012 HUBzero Foundation, LLC.
+ * Copyright (c) 2005-2013 HUBzero Foundation, LLC.
  *
  * This file is part of: The HUBzero(R) Platform for Scientific Collaboration
  *
@@ -405,6 +406,7 @@ char group[100];
 int gid;
 int do_debug;
 int do_foreground;
+int no_mtab = 0;
 
 void error(const char *format, ...)
 {
@@ -427,6 +429,7 @@ void print_help(char *argv[])
     error("options:");
     error("    -d                enable debug output");
     error("    -f                run in foreground");
+    error("    -n                mount without writing in /etc/mtab");
     error("    -o opt,[opt...]   options");
 }
 
@@ -501,7 +504,7 @@ int main(int argc, char *argv[])
     while(1) {
         int c;
         int option_index;
-        c = getopt_long(argc-2,&argv[2], "+dhfo:", long_options, &option_index);
+        c = getopt_long(argc-2,&argv[2], "+ndhfo:", long_options, &option_index);
         if (c == -1) {
             break;
         }
@@ -512,6 +515,9 @@ int main(int argc, char *argv[])
             case PRINT_HELP:
                 print_help(argv);
                 return 0;
+            case 'n':
+                no_mtab=1;
+                break;
             case 'd':
                 do_debug=1;
                 do_foreground=1;
